@@ -21,7 +21,6 @@
 #
 # Imports
 #
-import binascii
 import io
 from typing import List, Optional, Tuple, Union
 from aes_cipher.aes_cbc_encrypter import AesCbcEncrypter
@@ -37,6 +36,10 @@ from aes_cipher.utils import Utils
 
 # Data encrypter class
 class DataEncrypter:
+
+    encrypted_data: bytes
+    logger: Logger
+
     # Constructor
     def __init__(self,
                  logger: Logger = Logger()) -> None:
@@ -50,16 +53,17 @@ class DataEncrypter:
                 salt: Optional[Union[str, bytes]] = None,
                 itr_num: Optional[int] = None) -> None:
         # Log
-        self.logger.GetLogger().info("Salt: %s" % salt)
+        if salt is not None:
+            self.logger.GetLogger().info(f"Salt: {Utils.DataToString(salt)}")
 
         # Initialize current data
-        curr_data = data
+        curr_data = Utils.Encode(data)
 
         # Encrypt multiple times, one for each given password
         for password in passwords:
             # Log
-            self.logger.GetLogger().info("Encrypting with password: %s" % password)
-            self.logger.GetLogger().info("  Current data: %s" % binascii.hexlify(Utils.Encode(curr_data)))
+            self.logger.GetLogger().info(f"Encrypting with password: {Utils.DataToString(password)}")
+            self.logger.GetLogger().info(f"  Current data: {Utils.DataToString(curr_data)}")
 
             # Generate keys and IVs
             key_iv_gen = KeyIvGenerator()
@@ -79,7 +83,7 @@ class DataEncrypter:
             data_buffer.write(data_digest)
 
             # Log
-            self.logger.GetLogger().info("  Buffer: %s" % binascii.hexlify(data_buffer.getvalue()))
+            self.logger.GetLogger().info(f"  Buffer: {Utils.BytesToHexStr(data_buffer.getvalue())}")
 
             # Update current data
             curr_data = data_buffer.getvalue()
@@ -98,11 +102,12 @@ class DataEncrypter:
         aes_encrypter.Encrypt(key_iv_gen.GetInternalKey() + key_iv_gen.GetInternalIV())
         key_iv_encrypted = aes_encrypter.GetEncryptedData()
         # Compute their digest
-        key_iv_digest = HmacSha256.QuickDigest(key_iv_gen.GetMasterKey(), key_iv_gen.GetInternalKey() + key_iv_gen.GetInternalIV())
+        key_iv_digest = HmacSha256.QuickDigest(key_iv_gen.GetMasterKey(),
+                                               key_iv_gen.GetInternalKey() + key_iv_gen.GetInternalIV())
 
         # Log
-        self.logger.GetLogger().info("  Encrypted internal key/IV: %s" % binascii.hexlify(key_iv_encrypted))
-        self.logger.GetLogger().info("  Internal key/IV digest: %s" % binascii.hexlify(key_iv_digest))
+        self.logger.GetLogger().info(f"  Encrypted internal key/IV: {Utils.BytesToHexStr(key_iv_encrypted)}")
+        self.logger.GetLogger().info(f"  Internal key/IV digest: {Utils.BytesToHexStr(key_iv_digest)}")
 
         return key_iv_encrypted, key_iv_digest
 
@@ -118,7 +123,7 @@ class DataEncrypter:
         data_digest = HmacSha256.QuickDigest(key_iv_gen.GetInternalKey(), data)
 
         # Log
-        self.logger.GetLogger().info("  Encrypted data: %s" % binascii.hexlify(data_encrypted))
-        self.logger.GetLogger().info("  Data digest: %s" % binascii.hexlify(data_digest))
+        self.logger.GetLogger().info(f"  Encrypted data: {Utils.BytesToHexStr(data_encrypted)}")
+        self.logger.GetLogger().info(f"  Data digest: {Utils.BytesToHexStr(data_digest)}")
 
         return data_encrypted, data_digest
