@@ -26,7 +26,7 @@
 class FileReader:
     # Read file
     @staticmethod
-    def Read(file_in):
+    def Read(file_in: str) -> bytes:
         with open(file_in, "rb") as fin:
             file_data = fin.read()
 
